checkCompatibility <- function(ped, alleles, nAllele, sampleInfoLen, 
                               nFamily, familySize, markerNames, 
                               quiet=FALSE)
{
  nr <- nrow(ped)
  nc <- ncol(ped)

  ## sort ped according to pedigree id (i.e. family)
  ped2 <- ped[order(ped[, 1]), ]

  nr<-as.integer(nr)
  nc<-as.integer(nc)
  ped2<-as.integer(as.vector(t(ped2)))
  alleles<-as.integer(alleles)
  nAllele<-as.integer(nAllele)
  nFamily<-as.integer(nFamily)
  familySize<-as.integer(familySize)
  sampleInfoLen<-as.integer(sampleInfoLen)

  res<-.C("checkCompatible",
          ped2,
          nr,
          nc,
          nFamily,
          familySize,
          alleles,
          nAllele,
          sampleInfoLen,
          compatibleFlag=as.integer(1),
          errorFlag=as.integer(0),
          whichMarker=as.integer(0),
          quiet=as.integer(quiet),
          PACKAGE="fbat"
          )

  compatibleFlag <- res$compatibleFlag
  errorFlag <- res$errorFlag

  if(errorFlag==0)
      return(0)
  
  if(compatibleFlag==0)
      warning(
              "One or more sets of parent genotypes are not compatible ", 
              "with the corresponding child's genotypes. Such ", 
              "nuclear families will be excluded from analysis."
              )
  
  return(errorFlag)
}
