#Basic data quality checks for markers

checkMarkers<-function(geneSetObj, founderOnly=TRUE, thrsh=0.05, quiet=TRUE)
{
  Name<-markerNames(geneSetObj)
  res<-pedHardyWeinberg(geneSetObj, founderOnly=founderOnly, quiet=quiet)
  resMat<-res$resMat
  # number of observed heterozygotes
  nObsHET<-resMat[,3]
  # number of observed homozygotes
  nObsHOM<-resMat[,4]
  # number of genotypes containing missing allele
  nMissing<-resMat[,6]
  # total number of genotypes excluding genotypes containing missing alleles
  totalGeno<-nObsHET+nObsHOM
  # proportion of observed heterozygotes
  ObsHET<-nObsHET/totalGeno

  # proportion of call rate
  # i.e., percentage of non-missing genotypes for markers
  totalGeno2<-totalGeno+nMissing
  pGeno<-100*(1-nMissing/totalGeno2)

  # pvalues of HW test
  HWpval<-resMat[,9]

  # which markers pass HW test
  pos<-which(HWpval>thrsh)
  Rating<-rep(0, length(Name))
  Rating[pos]<-1 # pass HW test

  # MAF (missing allele excluded)
  res.a<-pedAFreq(CAMP, founderOnly=founderOnly, quiet=quiet)
  # allele counts
  aFreqMat<-res.a$aFreqMat[,-1] # first column is for missing allele
  aPercMat<-aFreqMat
  aSum<-apply(aFreqMat,1, sum)
  aPercMat[,1]<-aFreqMat[,1]/aSum
  aPercMat[,2]<-aFreqMat[,2]/aSum
  MAF<-apply(aPercMat, 1, min)

  # predicted heterozygosity (i.e., 2*MAF*(1-MAF))
  PredHET<-2*MAF*(1-MAF)

  if(!is.null(markerInfo(geneSetObj)$Position))
    Position<-markerInfo(geneSetObj)$Position
  else
    Position<-rep("?", length(Name))

  dFrame<-data.frame(Name=Name, Position=Position, ObsHET=ObsHET, PredHET=PredHET, HWpval=HWpval, pGeno=pGeno, MAF=MAF, Rating=Rating)

  return(dFrame)
}

