
# Transform a geneSet object to a ped matrix
# (rows are subjects, columns are markers; 2*nMarkers columns)
#
geneSet2Ped<-function(geneSetObject) 
{ 

  sampleInfo<-geneSetObject@sampleInfo

  len<-ncol(sampleInfo)

  if(ncol(sampleInfo)<5 || is.integer(sampleInfo[1,5])==FALSE)
      stop("`sampleInfo' must include at least 5 columns: ",
           "family, pid, father, mother, sex, [affected].")

  if(len==5) { sampleInfo<-sampleInfo[,1:5] }  
  else {
    if(is.integer(sampleInfo[1,6]) ==FALSE)
      sampleInfo<-sampleInfo[,1:5] 
    else 
      sampleInfo<-sampleInfo[,1:6]
  }

  columns<-colnames(sampleInfo)

  geneInfo<-alleleCodes(geneSetObject)

  ped<-cbind(as.matrix(sampleInfo), geneInfo)
  
  invisible(list(ped=ped, columns=columns))
}

alleleCodes <- function(obj, which=c(1, 2))
{
  retval <- alleles(obj,which=which, codes=TRUE)
  retval[is.na(retval)] <- 0
  retval
}

