############################################

## get allele frequencies 
pedAFreq <- function(geneSetObj,
                     founderOnly=TRUE, quiet=FALSE)
{
  #cat("converting geneSet object to numerical matrix...\n")
  tmp<-geneSet2Ped(geneSetObj)
  ped<-tmp$ped
  columns<-tmp$columns

  res<-pedAFreq.default(ped, columns, founderOnly, quiet)   
  invisible(res)
}

##
## get allele frequencies 
pedAFreq.default <- function(ped,
                     columns=c("family", "pid", "father",
                               "mother", "sex", "affected"),
                     founderOnly=TRUE, quiet=FALSE)
{
  tmp <- checkColumn(ped, columns)
  ped<-tmp$ped
  columns<-tmp$columns
  len <- length(columns)

  markerNames <- getMarkerNames(ped, columns)

  if(founderOnly==TRUE)
  { ## get parental info
    mat1 <- ped[, c(3:4)]
    tmp <- mat1[, 1]+mat1[, 2]
    pos <- which(tmp==0)
    if(length(pos)==0)
    { stop("The pedigree data contains no parental information!\n") }
 
    ped <- ped[pos, ] 
  } 
  mat <- ped[, -c(1:len)] 

  nr <- nrow(mat)
  nc <- ncol(mat)
  nMarker <- nc/2 # number of markers

  ## unique alleles (might include missing allele coded as 0)
  alleles <- sort(unique(c(mat)))
  nAllele <- length(alleles)

  mat <- as.vector(t(mat))
  mat <- as.integer(mat)
  nr <- as.integer(nr)
  nMarker <- as.integer(nMarker)
  alleles <- as.integer(alleles)
  nAllele <- as.integer(nAllele)


  ##if(!is.loaded(symbol.C("getAFreq"))){ dyn.load("./GeneticsBase.so") }

  res <- .C( "getAFreq", mat, nr, nMarker, 
            alleles, nAllele,
            aFreqMat=as.integer(rep(0, nMarker*nAllele)),
            PACKAGE="fbat"
            )

  aFreqMat <- matrix(res$aFreqMat, nrow=nMarker, byrow=T)
  rownames(aFreqMat) <- markerNames
  colnames(aFreqMat) <- alleles

  aPercMat <- aFreqMat/(2.0*nr)
  tmpmat <- cbind(aFreqMat, round(aPercMat, 3))

  ##if(is.loaded(symbol.C("getAFreq"))){ dyn.unload("./GeneticsBase.so") }
  

  if(!quiet)
  { cat("allele frequencies and percentages>>>\n")
    print(tmpmat)
  }

  invisible(list(aFreqMat=aFreqMat, aPercMat=aPercMat))
   
}
