
## get observed genotype frequencies
pedGFreq <- function(geneSetObj, founderOnly=TRUE, quiet=FALSE)
{
  #cat("converting geneSet object to numerical matrix...\n")
  tmp<-geneSet2Ped(geneSetObj)
  ped<-tmp$ped
  columns<-tmp$columns

  res<-pedGFreq.default(ped, columns, founderOnly, quiet)
}


## get observed genotype frequencies
pedGFreq.default <- function(ped, columns=c("family", "pid", "father", "mother", "sex", "affected"), founderOnly=TRUE, quiet=FALSE)
{
  tmp <- checkColumn(ped, columns)
  ped<-tmp$ped
  columns<-tmp$columns
  len <- length(columns)

  if(founderOnly==TRUE)
  { ## get parental info
    mat1 <- ped[, c(3:4)]
    tmp <- mat1[, 1]+mat1[, 2]
    pos <- which(tmp==0)
    if(length(pos)==0)
    { stop("The pedigree data contains no parental information!\n") }
 
    ped<-ped[pos,]
  } 
  mat <- ped[, -c(1:len)]

  nr <- nrow(mat)
  nc <- ncol(mat)
  nMarker <- nc/2

  ## unique alleles (might include missing allele coded as 0)
  alleles <- sort(unique(c(mat)))
  nAllele <- length(alleles)
  nGenotype <- (nAllele+1)*nAllele/2

  alleles <- as.integer(alleles)
  nAllele <- as.integer(nAllele)
  genotypeNames <- rep("                                                     ", nGenotype)

  res1 <- .C("getAllGenotypes", alleles, nAllele,
             gMat=as.integer(rep(0, nGenotype*2)),
             genotypeNames=as.character(genotypeNames),
             PACKAGE="fbat"             
             )
  gMat <- res1$gMat
  genotypeNames <- res1$genotypeNames

  mat2 <- as.vector(t(mat))
  mat2 <- as.integer(mat2)
  nr <- as.integer(nr)
  nMarker <- as.integer(nMarker)
  nGenotype <- as.integer(nGenotype)
  gMat <- as.integer(gMat)

  res2 <- .C("getGFreq", mat2, nr, nMarker, gMat, nGenotype, 
             countMat=as.integer(rep(0, nMarker*nGenotype)),
             PACKAGE="fbat"
             )

  genotypeCounts <- matrix(res2$countMat, ncol=nGenotype, byrow=TRUE)

  markerNames <- getMarkerNames(ped, columns)
  colnames(genotypeCounts) <- genotypeNames
  rownames(genotypeCounts) <- markerNames

  genotypePerc <- genotypeCounts/nr
  colnames(genotypePerc) <- genotypeNames
  rownames(genotypePerc) <- markerNames

  if(!quiet)
    {
      cat("genotype counts>>>\n");
      print(genotypeCounts);
    }

  invisible(list(gFreqMat=genotypeCounts, gPercMat=genotypePerc))
}
