\name{checkMarkers}
\alias{checkMarkers}
\title{Basic data quality checks for markers}
\description{
Basic data quality checks for markers.
}
\usage{
checkMarkers(geneSetObj, founderOnly=TRUE, thrsh=0.05, quiet=TRUE)
}
\arguments{
  \item{geneSetObj}{a \code{geneSet} object.}
  \item{founderOnly}{indicates if using only founder info}
  \item{thrsh}{threshold for Hardy-Weinberg test. If the pvalue of the HW test for a marker is greater than \code{thrsh}, then the marker is a good marker.}
  \item{quiet}{print intermediate results if \code{quiet=FALSE}.}
}
\value{
 a data frame contains components: 
 \item{Name}{marker names.}
 \item{Position}{marker positions.}
 \item{ObsHET}{marker's observed heterozygosity (i.e., proportion of heterozygotes at markes). Missing alleles are excluded in the calculation.}
 \item{PredHET}{marker's predicted heterozygosity (i.e., \code{2*MAF*(1-MAF)}). Missing alleles are excluded in the calculation.}
 \item{HWpval}{pvalues for Hardy-Weinberg test}
 \item{pGeno}{percentage of non-missing genotypes for markes}
 \item{MAF}{minor allele frequencies. missing allele are excluded from calculation}
 \item{Rating}{\code{Rating[i]=1} means that the $i$-th marker passes HW test (do not reject H0 that HW equilibrium holds). \code{Rating[i]=0} means HW equilibrum does hold for the $i$-th marker.}
}
\author{Weiliang Qiu \email{stwxq@channing.harvard.edu}, Ross Lazarus \email{ross.lazarus@channing.harvard.edu}}
\examples{
  data(CAMP)
  res<-checkMarkers(CAMP)
  print(res)
}
\keyword{htest}

