\name{fbat}
\alias{fbat}
\alias{fbat.default}
\title{Family-Based Association Tests}
\description{
  Family-Based Assoiciation Tests for biallelic markers.
}
\usage{
  fbat(geneSetObj, 
       model="a", 
       traitMethod=3, 
       traitOffset=0, 
       quiet=TRUE)

  fbat.default(ped, 
               columns=c("family","pid","father","mother","sex","affected"), 
               model="a", 
               traitMethod=3, 
               traitOffset=0, 
               quiet=TRUE)
}
\arguments{
  \item{geneSetObj}{an object of \code{geneSet}.}
  \item{ped}{pedigree data frame whose first 6 columns are pid (pedigree id), id (individual id), fid (father id), mid (mother id), sex, aff (affection status). The remaining columns are pairs of marker alleles. Each row corresponds to an individual.}
  \item{columns}{names of the first 5 (or 6) columns of ped file. It should be either equal to  c("family","pid","father","mother","sex","affect") or equal to c("family","pid","father","mother","sex")}
  \item{model}{Genotype coding method. \code{model="d"} means GDOM (dominante) coding; \code{model="r"} means GREC (recessive) coding; \code{model="g"} means GEN (genotype) coding; \code{model="a"} or otherwise means GTDT (additive) coding.}

  \item{traitMethod}{Trait coding method. \code{traitMethod=1} means \code{T=y-offset}, where \code{y} is the trait and \code{offset} is an offset. In a .ped file, \code{y=2} if affected; \code{y=1} if unaffected; and \code{y=0} if unknown. \code{traitMethod=2} means \code{T=1} if affected, \code{T=0} otherwise.}

  \item{traitOffset}{Offset if \code{traitMethod=1}.}

  \item{quiet}{Print some intermediate results if \code{quiet=FALSE}.}
}
\value{
  \item{statPvalue}{A \code{m} by 3 matrix with the 3 columns: test statistics, degree of freedom and pvalues, where \code{m} is the number of markers.}
  \item{S.list}{A list of S scores for markers.}
  \item{ES.list}{A list of expected S scores for markers.}
  \item{CovS.list}{A list of covariance matrix of S scores for markers.}
  \item{alleles.list}{A list of alleles for markers}
  \item{familySize}{size of nuclear families}
  \item{flagMarkers}{A vector of flags. \code{flagMarkers[i]=1} if for marker \code{i}, all children genotypes in all families are missing. Otherwise \code{flagMarkers[i]=0}.}
  \item{numInfoFamily}{number of informative families at each marker}
}
\author{Weiliang Qiu \email{stwxq@channing.harvard.edu}, Ross Lazarus \email{ross.lazarus@channing.harvard.edu}}
\references{
  Horvath et al. 
  The family based association test method: computing means and variances for general statistics.
  \emph{Technical report \url{http://www.biostat.harvard.edu/~fbat/fbattechreport.ps}.}

  Rabinowitz and Laird (2000).
  A Unified Approach to Adjusting Association Tests for Population Admixture with Arbitrary Pedigree Structure and Arbitrary Missing Marker Information.
  \emph{Human Heredity \bold{50}:211-223.}  

  Laird et al. (2000).
  Implementing a Unified Approach to Family-Based Tests of Association.
  \emph{Genetic Epidemiology \bold{19(Suppl 1)}:S36-S42.}

  Schaid (1996).
  General Score Tests for Associations of Genetic Markers With Disease Using Cases and Their Parents.
  \emph{Genetic Epidemiology \bold{13}:423-449.}
}
\examples{
  data(CAMP)
  tmp<-fbat(CAMP)
  summaryPvalue(tmp)
}
\keyword{htest}

